@@ -50,8 +50,8 @@ class RemovedReason(Enum):
 	
 	DeletedByThisClient = 8
 	DeletedByOtherClient = 9
-	
 	ButtonBelongsToOtherPartner = 10
+	DeletedFromButton = 11
 
 class ClickType(Enum):
 	ButtonDown = 0
@@ -84,13 +84,14 @@ class ScanWizardResult(Enum):
 	WizardInternetBackendError = 5
 	WizardInvalidData = 6
 	WizardButtonBelongsToOtherPartner = 7
+	WizardButtonAlreadyConnectedToOtherDevice = 8
 
 class ButtonScanner:
 	"""ButtonScanner class.
 	
 	Usage:
 	scanner = ButtonScanner()
-	scanner.on_advertisement_packet = lambda scanner, bd_addr, name, rssi, is_private, already_verified: ...
+	scanner.on_advertisement_packet = lambda scanner, bd_addr, name, rssi, is_private, already_verified, already_connected_to_this_device, already_connected_to_other_device: ...
 	client.add_scanner(scanner)
 	"""
 	
@@ -98,7 +99,7 @@ class ButtonScanner:
 	
 	def __init__(self):
 		self._scan_id = next(ButtonScanner._cnt)
-		self.on_advertisement_packet = lambda scanner, bd_addr, name, rssi, is_private, already_verified: None
+		self.on_advertisement_packet = lambda scanner, bd_addr, name, rssi, is_private, already_verified, already_connected_to_this_device, already_connected_to_other_device: None
 
 class ScanWizard:
 	"""ScanWizard class
@@ -236,7 +237,7 @@ class FlicClient:
 	"""
 	
 	_EVENTS = [
-		("EvtAdvertisementPacket", "<I6s17pb??", "scan_id bd_addr name rssi is_private already_verified"),
+		("EvtAdvertisementPacket", "<I6s17pb????", "scan_id bd_addr name rssi is_private already_verified already_connected_to_this_device already_connected_to_other_device"),
 		("EvtCreateConnectionChannelResponse", "<IBB", "conn_id error connection_status"),
 		("EvtConnectionStatusChanged", "<IBB", "conn_id connection_status disconnect_reason"),
 		("EvtConnectionChannelRemoved", "<IB", "conn_id removed_reason"),
@@ -250,7 +251,7 @@ class FlicClient:
 		("EvtGotSpaceForNewConnection", "<B", "max_concurrently_connected_buttons"),
 		("EvtBluetoothControllerStateChange", "<B", "state"),
 		("EvtPingResponse", "<I", "ping_id"),
-		("EvtGetButtonInfoResponse", "<6s16s17p", "bd_addr uuid color"),
+		("EvtGetButtonInfoResponse", "<6s16s17p17p", "bd_addr uuid color serial_number"),
 		("EvtScanWizardFoundPrivateButton", "<I", "scan_wizard_id"),
 		("EvtScanWizardFoundPublicButton", "<I6s17p", "scan_wizard_id bd_addr name"),
 		("EvtScanWizardButtonConnected", "<I", "scan_wizard_id"),
@@ -447,7 +448,7 @@ class FlicClient:
 		The server will send back its information directly and the callback will be called once the response arrives.
 		Responses will arrive in the same order as requested.
 		
-		The callback takes three parameters: bd_addr, uuid (hex string of 32 characters), color (string and None if unknown).
+		The callback takes four parameters: bd_addr, uuid (hex string of 32 characters), color (string and None if unknown), serial_number.
 		
 		Note: if the button isn't verified, the uuid sent to the callback will rather be None.
 		"""
@@ -544,8 +545,11 @@ class FlicClient:
 			if items["uuid"] == "00000000000000000000000000000000":
 				items["uuid"] = None
 			items["color"] = items["color"].decode("utf-8")
-			if (items["color"] == ""):
+			if items["color"] == "":
 				items["color"] = None
+			items["serial_number"] = items["serial_number"].decode("utf-8")
+			if items["serial_number"] == "":
+				items["serial_number"] = None
 		
 		if event_name == "EvtScanWizardCompleted":
 			items["result"] = ScanWizardResult(items["result"])
@@ -554,7 +558,7 @@ class FlicClient:
 		if event_name == "EvtAdvertisementPacket":
 			scanner = self._scanners.get(items["scan_id"])
 			if scanner is not None:
-				scanner.on_advertisement_packet(scanner, items["bd_addr"], items["name"], items["rssi"], items["is_private"], items["already_verified"])
+				scanner.on_advertisement_packet(scanner, items["bd_addr"], items["name"], items["rssi"], items["is_private"], items["already_verified"], items["already_connected_to_this_device"], items["already_connected_to_other_device"])
 		
 		if event_name == "EvtCreateConnectionChannelResponse":
 			channel = self._connection_channels[items["conn_id"]]
@@ -600,7 +604,7 @@ class FlicClient:
 			self.on_bluetooth_controller_state_change(items["state"])
 		
 		if event_name == "EvtGetButtonInfoResponse":
-			self._get_button_info_queue.get()(items["bd_addr"], items["uuid"], items["color"])
+			self._get_button_info_queue.get()(items["bd_addr"], items["uuid"], items["color"], items["serial_number"])
 		
 		if event_name == "EvtScanWizardFoundPrivateButton":
 			scan_wizard = self._scan_wizards[items["scan_wizard_id"]]
